@@ -540,13 +540,29 @@ sub classical { return shift }
 sub plural {
     my $self   = shift;
     my $person = shift // 0;
+
     my $term = $term_of{$self};
 
-    return $encase->(
-                $term,
-                $noun_inflexion_of{lc $term}{plural}[$person]
-                // Lingua::EN::Inflexion::Nouns::convert_to_classical_plural($term, $person)
-           );
+    # Prepositions imply objective or possessive (or dative)...
+    my $preposition = $term =~ s{ \A ( \s* $PREP_PAT \s+ ) }{}xi ? $1 : q{};
+
+
+    return
+        $preposition ? $preposition
+                       . $encase->( $term,
+                              $noun_inflexion_of{objective }{lc $term}{plural}[$person]
+                           // $noun_inflexion_of{possessive}{lc $term}{plural}[$person]
+                           // $noun_inflexion_of{reflexive }{lc $term}{plural}[$person]
+                           // $noun_inflexion_of{nominative}{lc $term}{plural}[$person]
+                           // Lingua::EN::Inflexion::Nouns::convert_to_classical_plural($term,$person)
+                         )
+                     :   $encase->( $term,
+                              $noun_inflexion_of{nominative}{lc $term}{plural}[$person]
+                           // $noun_inflexion_of{objective }{lc $term}{plural}[$person]
+                           // $noun_inflexion_of{possessive}{lc $term}{plural}[$person]
+                           // $noun_inflexion_of{reflexive }{lc $term}{plural}[$person]
+                           // Lingua::EN::Inflexion::Nouns::convert_to_classical_plural($term,$person)
+                         );
 }
 
 package Lingua::EN::Inflexion::Verb;
